summaryrefslogtreecommitdiffstats
path: root/urpm.pm
diff options
context:
space:
mode:
authorRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2005-06-29 02:42:27 +0000
committerRafael Garcia-Suarez <rgarciasuarez@mandriva.org>2005-06-29 02:42:27 +0000
commit999a07db7b69bfffb350ed0c439f7ea3deb2a14c (patch)
treec5d5aedf881d4fcc996ab905b7274b9969d99f0d /urpm.pm
parentc72ae1c2a0aa6701521129756ef80ca83376e662 (diff)
downloadurpmi-999a07db7b69bfffb350ed0c439f7ea3deb2a14c.tar
urpmi-999a07db7b69bfffb350ed0c439f7ea3deb2a14c.tar.gz
urpmi-999a07db7b69bfffb350ed0c439f7ea3deb2a14c.tar.bz2
urpmi-999a07db7b69bfffb350ed0c439f7ea3deb2a14c.tar.xz
urpmi-999a07db7b69bfffb350ed0c439f7ea3deb2a14c.zip
Add an experimental --restricted option, based on code by Michael Scherer
(bug #16610)
Diffstat (limited to 'urpm.pm')
-rw-r--r--urpm.pm11
1 files changed, 8 insertions, 3 deletions
diff --git a/urpm.pm b/urpm.pm
index dd1b9130..f054e602 100644
--- a/urpm.pm
+++ b/urpm.pm
@@ -1802,7 +1802,7 @@ this could happen if you mounted manually the directory when creating the medium
$error = 1, $urpm->{error}(N("nothing written in list file for \"%s\"", $medium->{name}));
}
} else {
#- the flag is no more necessary.
if ($medium->{list}) {
unlink "$urpm->{statedir}/$medium->{list}";
delete $medium->{list};
@@ -1864,7 +1864,7 @@ this could happen if you mounted manually the directory when creating the medium
if ($medium->{list}) {
urpm::util::move("$urpm->{cachedir}/partial/$medium->{list}", "$urpm->{statedir}/$medium->{list}");
}
- $medium->{md5sum} = $retrieved_md5sum; #- anyway, keep it, the previous one is no more useful.
+ $medium->{md5sum} = $retrieved_md5sum; #- anyway, keep it, the previous one is no longer useful.
#- and create synthesis file associated.
$medium->{modified_synthesis} = !$medium->{synthesis};
@@ -1957,7 +1957,7 @@ this could happen if you mounted manually the directory when creating the medium
$options{callback} && $options{callback}('done', $medium->{name});
}
#- clean headers cache directory to remove everything that is no more
#- useful according to the depslist.
if ($urpm->{modified}) {
if ($options{noclean}) {
@@ -3370,6 +3370,11 @@ sub opendir_safe {
return $d;
}
+sub error_restricted ($) {
+ my ($urpm) = @_;
+ $urpm->{fatal}(2, N("Error, this operation is forbidden while running in restricted mode"));
+}
+
sub DESTROY {}
1;
@@ -1802,7 +1802,7 @@ this could happen if you mounted manually the directory when creating the medium
}
} else {
- #- the flag is no more necessary.
+ #- the flag is no longer necessary.
if ($medium->{list}) {
unlink "$urpm->{statedir}/$medium->{list}";
@@ -1957,7 +1957,7 @@ this could happen if you mounted manually the directory when creating the medium
$options{callback} && $options{callback}('done', $medium->{name});
}
- #- clean headers cache directory to remove everything that is no more
+ #- clean headers cache directory to remove everything that is no longer
#- useful according to the depslist.
if ($urpm->{modified}) {